import { Drawer, PageHeader } from 'antd'
import type { DrawerProps } from 'antd'
import type { PropsWithChildren, FC } from 'react'
import styles from './index.less'
import { useModel } from '@umijs/max'
type AnimateContentProps = {
  visible: boolean
  onVisibleChange: (visible: boolean) => void
  disableBreadcrumb?: boolean
} & Omit<DrawerProps, 'visible' | 'onVisibleChange'>

const AnimateContent: FC<PropsWithChildren<AnimateContentProps>> = ({
  visible,
  onVisibleChange,
  children,
  title,
  ...others
}) => {
  const wrapHeight = document.querySelector('.ant-pro-page-container-warp')?.clientHeight || 0
  const {
    initialState: { setting: { collapsed } = { collapsed: false } }
  } = useModel('@@initialState')
  return (
    <div className={styles.pageContainer}>
      <Drawer
        {...others}
        title={<PageHeader title={title} onBack={() => onVisibleChange(false)} />}
        getContainer={false}
        visible={visible}
        push={false}
        onClose={() => onVisibleChange(false)}
        mask={false}
        width={`calc(100vw - ${collapsed ? 48 : 256}px - 48px)`}
        style={{ right: '24px', top: `${48 + wrapHeight}px` }}
        contentWrapperStyle={{
          height: `calc(100vh - 72px - ${wrapHeight}px)`
        }}
        // closeIcon={<Button onClick={() => onVisibleChange(false)}>返回</Button>}>
      >
        {visible ? children : null}
      </Drawer>
    </div>
  )
}

export default AnimateContent
