import { PageContainer } from '@ant-design/pro-layout'
import { Table } from 'antd'
import { ColumnsType } from 'antd/lib/table'
import { useRowScript } from './hooks/useRowScript'

enum TemplateMode {
  PAPER = 'paper',
  UPLOAD = 'upload',
  ALL = 'all'
}

const Inventory = () => {
  const { list } = useRowScript()
  const columns: ColumnsType<API.ProfileTemplateItem> = [
    {
      title: '序号',
      dataIndex: 'sort',
      width: 120
    },
    {
      title: '目录文件名称',
      dataIndex: 'name'
    },
    {
      title: '状态',
      dataIndex: 'enable',
      render: text =>
        text ? <span className="text-green">启用</span> : <span className="text-red">停用</span>
    },
    {
      title: '是否必填',
      dataIndex: 'required',
      render: text => (text ? '是' : '否')
    },
    {
      title: '资料提供方式',
      dataIndex: 'mode',
      render: (mode: TemplateMode) => (
        <div>
          {[TemplateMode.PAPER, TemplateMode.ALL].includes(mode) && (
            <span className="border border-hex-91d5ff text-blue bg-hex-e6f7ff rounded-1 px-1 text-sm">
              纸质
            </span>
          )}
          {[TemplateMode.UPLOAD, TemplateMode.ALL].includes(mode) && (
            <span className="border border-hex-9fede5 text-hex-13c2c2 bg-hex-e6fffb rounded-1 px-1 ml-2 text-sm">
              上传
            </span>
          )}
        </div>
      )
    }
  ]
  return (
    <PageContainer title={false}>
      {list?.length && (
        <Table
          rowKey="ID"
          columns={columns}
          dataSource={list}
          pagination={false}
          size="small"
          bordered
          expandable={{ defaultExpandAllRows: true }}
        />
      )}
    </PageContainer>
  )
}

export default Inventory
