// import { getProjectTypeList } from '@/services/api/project'
// import consts from '@/utils/consts'
import { queryInstitutionList } from '@/services/api/institution'
import consts from '@/utils/consts'
import type { Effect, Reducer } from '@umijs/max'

export interface BusinessModelState {
  dataID: string
  institutionList: API.InstitutionList[]
}

export interface BusinessModelType {
  namespace: 'business'
  state: BusinessModelState
  effects: {
    queryInstitution: Effect
  }
  reducers: {
    save: Reducer<BusinessModelState>
    // 启用 immer 之后
    // save: ImmerReducer<ProjectModelState>;
  }
}

const BusinessModel: BusinessModelType = {
  namespace: 'business',
  state: {
    institutionList: []
  },
  effects: {
    *queryInstitution({ payload }, { call, put }) {
      const response = yield call(queryInstitutionList, payload)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            institutionList: response.data
          }
        })
      }
    }
  },
  reducers: {
    save(state, action) {
      return {
        ...state,
        ...action.payload
      }
    }
    // 启用 immer 之后
    // save(state, action) {
    //   state.name = action.payload;
    // },
  }
}

export default BusinessModel
