import type { FC } from 'react'
import { useState } from 'react'
import { useEffect, useRef } from 'react'
import { Card, Form, InputNumber, message } from 'antd'

import type { ProFormInstance } from '@ant-design/pro-form'
import ProForm, { ProFormSelect } from '@ant-design/pro-form'
import consts from '@/utils/consts'
import { queryAccountList, saveInstitutionSetting } from '@/services/api/institution'
import { useRequest } from '@umijs/max'

interface RoleProps {
  dataID: string
  memberTotal: number
  managerID: string
  initData: () => void
}

const Role: FC<RoleProps> = ({ initData, dataID, memberTotal, managerID }) => {
  const [list, setList] = useState([])
  const ref = useRef<ProFormInstance>(null)
  const { run: trySave } = useRequest(saveInstitutionSetting, {
    manual: true,
    onSuccess: () => {
      initData()
      return message.success('设置成功')
    }
  })
  useRequest(() => queryAccountList({ current: 1, pageSize: 214000, accountType: '1', dataID }), {
    onSuccess: result => {
      setList(result.items?.map(item => ({ label: item.name, value: item.ID })))
      // eslint-disable-next-line no-unused-expressions
      ref.current?.setFieldsValue({ accountID: managerID, memberTotal })
    }
  })
  return (
    <Card>
      <ProForm
        formRef={ref}
        wrapperCol={{ span: 6 }}
        onFinish={async values => {
          await trySave({ ...values, ID: dataID })
        }}>
        <ProFormSelect
          label="单位管理员："
          tooltip="管理员可在前台维护单位信息和维护单位下成员"
          name="accountID"
          rules={[{ required: true, message: '请选择单位管理员' }]}
          options={list}
        />
        <Form.Item
          label="最大成员数量："
          tooltip={`已有成员${memberTotal}`}
          name="memberTotal"
          rules={[{ required: true, message: '请输入成员总数' }]}>
          <InputNumber style={{ width: '100%' }} />
        </Form.Item>
      </ProForm>
    </Card>
  )
}

export default Role
