import ProTable from '@ant-design/pro-table'
import type { ProColumnType } from '@ant-design/pro-table'
import React, { useState, useEffect, useRef, useMemo } from 'react'
import { Button, Tooltip } from 'antd'
import consts from '@/utils/consts'
import { connect } from '@umijs/max'
import dayjs from 'dayjs'
import { queryAccountList } from '@/services/api/institution'
import StaffDetail from '@/pages/Institutions/Staff/components/StaffDetail'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { generateColumns } from '@/utils/util'
import AnimateContent from '@/components/AnimateContent'
import { ModalType } from '@/utils/enum'
import IconFont from '@/components/IconFont'
import type { ColumnsStateType } from '@ant-design/pro-table/lib/typing'

type ListProps = ConnectProps & {
  accountType: API.AccountType[]
  memberTotal: number
  dataID: string
  companyName: string
  managerID: string
}
const Staff: React.FC<ListProps> = ({
  schema,
  dataID,
  companyName,
  dispatch,
  accountTypeList,
  memberTotal = 3,
  managerID
}) => {
  const tRef = useRef<ActionType>(null)
  const [state, setState] = useState({
    params: {
      search: null,
      accountType: '1',
      dataID
    },
    title: '',
    visible: false,
    currentModalType: ModalType.ADD,
    defaultFormData: {},
    total: null
  })
  useEffect(() => {
    dispatch({
      type: 'schemaBase/querySchema',
      payload: {
        columnType: BaseMenuEnum.STAFF
      }
    })
  }, [])

  const columns: ProColumnType<API.AccountListItem>[] = [
    {
      dataIndex: 'account',
      title: '帐号',
      width: 116,
      onHeaderCell: () => ({ style: { textAlign: 'center' } })
    },
    {
      dataIndex: 'name',
      title: '姓名',
      renderText: (text, record) => (
        <div className="flex flex-row items-center">
          <div>{text}</div>
          <div className="ml-1 text-16px">
            {record.ID === managerID ? <IconFont type="icon-admin" /> : null}
          </div>
        </div>
      ),
      width: 86,
      onHeaderCell: () => ({ style: { textAlign: 'center' } })
    },
    {
      dataIndex: 'enable',
      key: 'enable',
      title: '状态',
      filters: true,
      width: 82,
      align: 'center',
      defaultFilteredValue: ['true'],
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      filterMultiple: false,
      valueEnum: {
        true: { text: '启用', status: 'Success' },
        false: { text: '禁用', status: 'Error' }
      }
    },
    // {
    //   dataIndex: 'gender',
    //   key: 'gender',
    //   title: '性别',
    //   width: 72,
    //   align: 'center',
    //   onHeaderCell: () => ({ style: { textAlign: 'center' } }),
    //   render: (_, { gender }) => {
    //     return <span>{genderEum[gender]}</span>
    //   }
    // },
    {
      dataIndex: 'position',
      key: 'position',
      title: '职位',
      align: 'cnenter',
      width: 120,
      ellipsis: true,
      onHeaderCell: () => ({ style: { textAlign: 'center' } })
    },
    {
      dataIndex: 'organizationalStructureID',
      key: 'organizationalStructureID',
      title: '组织架构',
      width: 146,
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      renderText: (_, record) => record.organizationalStructure?.name
    },
    {
      dataIndex: 'institutionID',
      key: 'institutionID',
      title: '所属企事业单位',
      width: 286,
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      renderText: (_, record) => record.institution.name
    },
    {
      dataIndex: 'contactMobile',
      key: 'contactMobile',
      title: '联系手机',
      width: 116,
      align: 'center',
      onHeaderCell: () => ({ style: { textAlign: 'center' } })
    },
    {
      dataIndex: 'officePhone',
      key: 'officePhone',
      title: '办公电话',
      width: 136,
      align: 'center',
      onHeaderCell: () => ({ style: { textAlign: 'center' } })
    },
    {
      dataIndex: 'createdTime',
      key: 'createdTime',
      title: '创建时间',
      width: 106,
      align: 'center',
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      renderText: text => dayjs(text).format('YYYY-MM-DD')
    },
    {
      dataIndex: 'created',
      key: 'created',
      title: '创建者',
      width: 116,
      align: 'center',
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      renderText: (_, record) => record?.created?.name
    },
    {
      title: '操作',
      dataIndex: 'operate',
      width: 61,
      align: 'center',
      onHeaderCell: () => ({ style: { textAlign: 'center' } }),
      render: (_, record) => (
        <div className="divide-x divide-bg-gray-400 flex flex-row justify-center">
          <div
            className="pr-2 text-primary cursor-pointer hover:text-hex-967bbd"
            onClick={() => {
              setState({
                ...state,
                visible: true,
                currentModalType: ModalType.UPDATE,
                title: record.name,
                defaultFormData: record
              })
            }}>
            编辑
          </div>
        </div>
      )
    }
  ]

  const wrapHeight = document.querySelector('.ant-pro-page-container-warp')?.clientHeight || 0

  const columnsState: ColumnsStateType = useMemo(
    () => ({
      persistenceKey: 'staff_list_column_key',
      persistenceType: 'localStorage'
    }),
    []
  )

  return (
    <div>
      <ProTable<API.AccountListItem>
        rowKey="ID"
        params={state.params}
        actionRef={tRef}
        scroll={{
          y: document.body.clientHeight - (263 + wrapHeight)
        }}
        columnsState={columnsState}
        columns={generateColumns(columns, schema)}
        search={false}
        request={async (params, filter, sorter) => {
          const { code = -1, data: { items = [], total = 0, iCount = 0 } = {} } = await queryAccountList({
            ...params,
            ...filter,
            ...sorter
          })

          setState({ ...state, total: iCount })
          return {
            data: items,
            success: code === consts.RET_CODE.SUCCESS,
            total
          }
        }}
        toolbar={{
          search: {
            onSearch: val => setState({ ...state, params: { ...state.params, search: val } })
          },
          actions: [
            state.total && state.total >= memberTotal ? (
              <Tooltip placement="top" title="成员已满，无法新增">
                <Button type="primary" disabled>
                  添加人员
                </Button>
              </Tooltip>
            ) : (
              <Button
                type="primary"
                onClick={() => {
                  setState({
                    ...state,
                    visible: true,
                    currentModalType: ModalType.ADD,
                    institutionDisable: true,
                    title: '',
                    defaultFormData: {
                      institutionID: dataID,
                      institution: {
                        ID: dataID,
                        name: companyName
                      }
                    }
                  })
                }}>
                添加人员
              </Button>
            )
          ]
        }}
      />
      <AnimateContent
        title={
          <>
            {state.currentModalType === ModalType.ADD ? '新增账号' : null}
            {state.currentModalType === ModalType.UPDATE ? `编辑账号(${state.title})` : null}
          </>
        }
        visible={state.visible}
        onVisibleChange={visible => setState({ ...state, visible })}>
        <StaffDetail
          onVisibleChange={(visible: boolean) => setState({ ...state, visible })}
          type={state.currentModalType}
          defaultFormData={{ ...state.defaultFormData }}
          accountTypeList={accountTypeList}
          reload={() => tRef.current?.reload()}
        />
      </AnimateContent>
    </div>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  schema: schemaBase.base[BaseMenuEnum.STAFF]?.schema
}))(Staff)
