import React, { useEffect, useState } from 'react'
import Staff from './components/Staff'
import Organization from './components/Organization'
import Role from './components/Role'
import { PageContainer } from '@ant-design/pro-layout'
import { useParams, useRequest } from '@umijs/max'
import { queryInstitution } from '@/services/api/institution'

export enum TabEnum {
  STAFF = '0',
  ORGANIZATION = '1',
  ROLE = '2'
}

const CompanyDetail: React.FC = () => {
  const { id: ID } = useParams()
  const [company, setCompany] = useState<Nullable<API.InstitutionListItem>>(null)
  const { run: tryQueryCompany } = useRequest(queryInstitution, {
    manual: true,
    onSuccess: result => {
      setCompany(result)
    }
  })
  function initData() {
    ID && tryQueryCompany({ ID })
  }
  useEffect(() => {
    initData()
  }, [ID])

  const menuMap: Record<string, string> = {
    [TabEnum.STAFF]: '人员管理',
    [TabEnum.ORGANIZATION]: '组织架构',
    [TabEnum.ROLE]: '单位设置'
  }
  const [selectKey, setSelectKey] = useState<TabEnum>(TabEnum.STAFF)

  const renderChildren = () => {
    switch (selectKey) {
      case TabEnum.STAFF:
        return (
          <Staff
            dataID={ID}
            companyName={company?.name}
            memberTotal={company?.memberTotal}
            managerID={company?.manager?.ID}
          />
        )
      case TabEnum.ORGANIZATION:
        return <Organization dataID={ID} />
      case TabEnum.ROLE:
        return (
          <Role
            initData={initData}
            dataID={ID}
            memberTotal={company?.memberTotal}
            managerID={company?.manager?.ID}
          />
        )
      default:
        return null
    }
  }

  return (
    company && (
      <PageContainer
        title={company.name}
        fixedHeader
        tabList={[
          { tab: menuMap[TabEnum.STAFF], key: TabEnum.STAFF },
          { tab: menuMap[TabEnum.ORGANIZATION], key: TabEnum.ORGANIZATION },
          { tab: menuMap[TabEnum.ROLE], key: TabEnum.ROLE }
        ]}
        onTabChange={key => setSelectKey(key)}>
        {renderChildren()}
      </PageContainer>
    )
  )
}

export default CompanyDetail
