import { connect, useRequest } from '@umijs/max'
import { useEffect } from 'react'
import { message } from 'antd'
import { addInstitution, updateInstitution } from '@/services/api/institution'
import { ModalType } from '@/utils/enum'
import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import type { ConnectProps } from '@umijs/max'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { createForm } from '@formily/core'
import {
  Form,
  FormButtonGroup,
  Submit,
  FormLayout,
  FormItem,
  TreeSelect,
  Input,
  Select,
  FormGrid,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  Cascader
} from '@formily/antd'
import { createSchemaField } from '@formily/react'

type CompanyModalProps = ConnectProps & {
  setVisible: (visible: boolean) => void
  type: ModalType
  defaultFormData?: API.InstitutionListItem
  reload: () => void
  companySchema?: Record<string, any> | null
}

const CompanyDrawer: React.FC<CompanyModalProps> = ({
  dispatch,
  setVisible,
  type,
  defaultFormData,
  companySchema,
  reload
}) => {
  const formInstance = createForm({
    validateFirst: true,
    initialValues: type === ModalType.UPDATE ? defaultFormData : null
  })

  const SchemaField = createSchemaField({
    components: {
      FormLayout,
      FormItem,
      FormGrid,
      Input,
      Select,
      Radio,
      Checkbox,
      NumberPicker,
      TreeSelect,
      Password,
      DatePicker,
      TimePicker,
      Cascader
    }
  })
  useEffect(() => {
    if (!companySchema) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType: BaseMenuEnum.COMPANY
        }
      })
    }
  }, [])
  const { run: tryUpdateInstitution } = useRequest(updateInstitution, {
    manual: true,
    onSuccess: () => {
      message.success('更新成功')
    }
  })
  const { run: tryAddInstitution } = useRequest(addInstitution, {
    manual: true,
    onSuccess: () => {
      message.success('创建成功')
    }
  })

  const onFinish = async formData => {
    try {
      // 执行表单提交
      if (type === ModalType.ADD) {
        await tryAddInstitution(formData)
      } else {
        await tryUpdateInstitution(formData)
      }
      setVisible(false)
      reload()
    } catch (error) {
      message.error(error)
    }
  }

  return (
    <div className="mt-6">
      <div className="max-w-800px">
        <Form form={formInstance} labelCol={6} wrapperCol={8}>
          <SchemaField schema={companySchema} />
          <FormButtonGroup.Sticky>
            <FormButtonGroup.FormItem labelCol={4}>
              <Submit onSubmit={onFinish}>提交</Submit>
            </FormButtonGroup.FormItem>
          </FormButtonGroup.Sticky>
        </Form>
      </div>
    </div>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  companySchema: schemaBase.base[BaseMenuEnum.COMPANY]
}))(CompanyDrawer)
