import ProForm, { ProFormSelect } from '@ant-design/pro-form'
import type { ProFormInstance } from '@ant-design/pro-form'
import React, { useEffect, useRef, useState } from 'react'
import { useRequest } from '@umijs/max'
import { getApprovalList, queryApprovalDetail, setApproval } from '@/services/api/project'
import { Card, message } from 'antd'
import consts from '@/utils/consts'

type AuditPermProps = {
  dataID: string
  defaultFormData: {
    approvalID?: string
  }
  initFn: () => void
}
const AuditPerm: React.FC<AuditPermProps> = ({ dataID, defaultFormData, initFn }) => {
  const ref = useRef<ProFormInstance>(null)
  const [approvalList, setApprovalList] = useState([])
  const [exist, setExist] = useState(false)
  const { run: trySetApproval } = useRequest(setApproval, {
    manual: true,
    onSuccess: () => {
      message.success('提交成功')
      initFn()
    }
  })
  const { run: tryQueryDetail } = useRequest(queryApprovalDetail, {
    manual: true,
    onSuccess: result => {
      if (result) {
        ref.current?.setFieldsValue({ ...defaultFormData })
        setExist(true)
      } else {
        // 查不到详情，需要触发表单校验
        ref.current?.validateFields()
      }
    }
  })
  useRequest(() => getApprovalList({ pageSize: 21500 }), {
    onSuccess: result => {
      setApprovalList(result?.items.map(item => ({ label: item.name, value: item.ID })) || [])
    }
  })
  useEffect(() => {
    if (defaultFormData?.approvalID) {
      tryQueryDetail({ ID: defaultFormData?.approvalID })
    }
  }, [defaultFormData?.approvalID])

  return (
    <Card>
      <div className="max-w-320px">
        <ProForm
          formRef={ref}
          submitter={{ resetButtonProps: false }}
          onFinish={async values => {
            const { code = -1 } = await trySetApproval({ ...values, ID: dataID })
            return code === consts.RET_CODE.SUCCESS
          }}>
          {/* <Form.Item label="指定人员" name="accountID">
            <TreeNodeSelect />
          </Form.Item> */}
          <ProFormSelect
            name="approvalID"
            label="审批流程"
            placeholder="请选择审批流程"
            options={approvalList}
            allowClear
            required
            showSearch
            rules={[
              {
                validator: (_, value) => {
                  if (value) return Promise.resolve(value)
                  if (defaultFormData.approvalID && !exist) {
                    return Promise.reject('原流程已删除，请重新选择')
                  }
                  return Promise.reject('请选择审批流程模板')
                }
              }
            ]}
          />
        </ProForm>
      </div>
    </Card>
  )
}

export default AuditPerm
