import { createForm, onFieldMount } from '@formily/core'
import { createSchemaField, FormProvider } from '@formily/react'
import {
  FormLayout,
  FormItem,
  Input,
  Select,
  FormGrid,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  TreeSelect,
  Cascader
} from '@formily/antd'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import type { ConnectProps } from '@umijs/max'
import { connect } from '@umijs/max'
import { useEffect } from 'react'
import { Card } from 'antd'

type ProjectInfoProps = ConnectProps & {
  projectSchema: Recordable<string>
  pTypeList: { label: string; value: string }[]
  defaultFormData: API.ProjectListItem
}

const ProjectInfo: React.FC<ProjectInfoProps> = ({ dispatch, pTypeList, projectSchema, defaultFormData }) => {
  useEffect(() => {
    if (!pTypeList.length) {
      dispatch({
        type: 'project/queryProjectTypeList'
      })
    }
    if (!projectSchema) {
      dispatch({
        type: 'schemaBase/querySchema',
        payload: {
          columnType: BaseMenuEnum.PROJECT
        }
      })
    }
  }, [])

  const formInstance = createForm({
    validateFirst: true,
    initialValues: defaultFormData,
    readPretty: true,
    effects() {
      onFieldMount('projectTypeID', field => {
        field.dataSource = pTypeList
      })
    }
  })

  const SchemaField = createSchemaField({
    components: {
      FormLayout,
      FormItem,
      Input,
      Select,
      FormGrid,
      Radio,
      Checkbox,
      NumberPicker,
      Password,
      DatePicker,
      TimePicker,
      TreeSelect,
      Cascader
    }
  })
  return (
    <Card>
      <div className="max-w-560px ">
        <FormProvider form={formInstance}>
          <SchemaField schema={projectSchema} />
        </FormProvider>
      </div>
    </Card>
  )
}

export default connect(
  ({ project, schemaBase }: { project: ProjectModelState; schemaBase: SchemaBaseModelState }) => ({
    pTypeList: project.projectTypeList.map(item => ({ label: item.name, value: item.ID })),
    projectSchema: schemaBase.base[BaseMenuEnum.PROJECT]
  })
)(ProjectInfo)
