import { getProject } from '@/services/api/project'
import { PageContainer } from '@ant-design/pro-layout'
import React, { useEffect, useState } from 'react'
import { useLocation, useParams, useRequest } from '@umijs/max'
import ProjectInfo from './components/ProjectInfo'
import type { RouteComponentProps } from 'umi/node_modules/@types/react-router'
import RolePerm from './components/RolePerm'
import AuditPerm from './components/AuditPerm'

export enum TabEnum {
  INFO = '0',
  STAFF_ROLE = '1',
  AUDIT_ROLE = '2'
}

const menuMap: Record<string, string> = {
  [TabEnum.INFO]: '项目信息',
  [TabEnum.STAFF_ROLE]: '角色权限',
  [TabEnum.AUDIT_ROLE]: '流程配置'
}

type ProjectDetailStateProps = {
  projectInfo: Nullable<API.ProjectListItem>
  selectKey: TabEnum
}
const ProjectDetail: React.FC<RouteComponentProps> = () => {
  const { id: ID } = useParams()

  const [state, setState] = useState<ProjectDetailStateProps>({
    projectInfo: null,
    selectKey: TabEnum.INFO
  })
  const { run: tryGetProjectInfo } = useRequest(getProject, {
    manual: true,
    onSuccess: (result: API.ProjectDetail) => setState({ ...state, projectInfo: result })
  })
  useEffect(() => {
    if (ID) {
      tryGetProjectInfo({ ID })
    }
  }, [ID])

  const renderChildren = () => {
    switch (state.selectKey) {
      case TabEnum.INFO:
        return <ProjectInfo defaultFormData={state.projectInfo} />
        break
      case TabEnum.STAFF_ROLE:
        return (
          <RolePerm
            dataID={state.projectInfo?.ID}
            defaultFormData={{
              createdID: state.projectInfo?.created?.ID,
              reportAccount: state.projectInfo?.reportAccount?.map(item => item.ID)
            }}
          />
        )
      case TabEnum.AUDIT_ROLE:
        return (
          <AuditPerm
            dataID={state.projectInfo?.ID}
            defaultFormData={{ approvalID: state.projectInfo?.approval.ID }}
            initFn={() => tryGetProjectInfo({ ID: dataID })}
          />
        )
      default:
        break
    }
  }

  return (
    state.projectInfo && (
      <PageContainer
        title={state.projectInfo?.name}
        fixedHeader
        tabList={[
          { tab: menuMap[TabEnum.INFO], key: TabEnum.INFO },
          { tab: menuMap[TabEnum.STAFF_ROLE], key: TabEnum.STAFF_ROLE },
          { tab: menuMap[TabEnum.AUDIT_ROLE], key: TabEnum.AUDIT_ROLE }
        ]}
        onTabChange={key => setState({ ...state, selectKey: key })}>
        {renderChildren()}
      </PageContainer>
    )
  )
}
export default ProjectDetail
