import { connect, useRequest } from '@umijs/max'
import { message } from 'antd'
import { addProject, updateProject } from '@/services/api/project'
import { BaseMenuEnum } from '@/pages/Schema/Base'
import { createForm } from '@formily/core'
import {
  Form,
  FormButtonGroup,
  Submit,
  FormLayout,
  FormGrid,
  FormItem,
  Input,
  Select,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  TreeSelect
} from '@formily/antd'
import { createSchemaField } from '@formily/react'

import type { SchemaBaseModelState } from '@/pages/Schema/Base/model'
import type { ConnectProps } from '@umijs/max'

export enum ModalType {
  ADD,
  UPDATE,
  PREVIEW
}

type ProjectModalProps = ConnectProps & {
  visible: boolean
  setVisible: (visible: boolean) => void
  type: ModalType
  defaultFormData: Record<string, any> | null
  pTypeList: API.ProjectTypeList
  reload: () => void
  projectSchema?: Record<string, any> | null
}
const ProjectModal: React.FC<ProjectModalProps> = ({
  setVisible,
  projectSchema,
  type,
  defaultFormData,
  reload
}) => {
  const formInstance = createForm({
    validateFirst: true,
    initialValues: type === ModalType.UPDATE ? defaultFormData : null
  })

  const SchemaField = createSchemaField({
    components: {
      FormLayout,
      FormItem,
      FormGrid,
      Input,
      Select,
      Radio,
      Checkbox,
      NumberPicker,
      Password,
      DatePicker,
      TimePicker,
      TreeSelect
    }
  })

  const { run: tryUpdateProject } = useRequest(updateProject, {
    manual: true,
    onSuccess: () => {
      message.success('更新成功')
    }
  })
  const { run: tryAddProject } = useRequest(addProject, {
    manual: true,
    onSuccess: () => {
      message.success('创建成功')
    }
  })

  const onFinish = async formData => {
    try {
      // 执行表单提交
      if (type === ModalType.ADD) {
        await tryAddProject(formData)
      } else {
        await tryUpdateProject({ ...formData, ID: defaultFormData.ID })
      }
      setVisible(false)
      reload()
    } catch (error) {
      message.error(error)
    }
  }

  return (
    <div className="max-w-800px mt-20px">
      <Form form={formInstance} labelCol={6} wrapperCol={10}>
        <SchemaField schema={projectSchema} />
        <FormButtonGroup.FormItem>
          <Submit onSubmit={onFinish}>提交</Submit>
        </FormButtonGroup.FormItem>
      </Form>
    </div>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  projectSchema: schemaBase.base[BaseMenuEnum.PROJECT]
}))(ProjectModal)
