import React, { useState } from 'react'
import { TreeSelect } from 'antd'
import { useRequest } from '@umijs/max'
import { queryAcountListByInstitutionID } from '@/services/api/institution'

const TreeNodeSelect = ({ params, onChange, placeholder = '请选择', exclusionRoleID, ...otherProps }) => {
  const [list, setList] = useState([])
  useRequest(() => queryAcountListByInstitutionID({ ...params, pageSize: 125000, exclusionRoleID }), {
    refreshDeps: [exclusionRoleID],
    onSuccess: result => {
      setList(result)
    }
  })

  const onNodeChange = (value, labelList) => {
    onChange?.(value, { value, label: labelList[0] })
  }
  const renderTreeNodes = data =>
    data.map(item => {
      const newItem = { ...item }

      if (newItem.children) {
        newItem.disabled = true
        newItem.children = renderTreeNodes(newItem.children)
        return newItem
      }
      return newItem
    })
  return list?.length ? (
    <TreeSelect
      {...otherProps}
      multiple
      showSearch
      allowClear
      style={{ width: '100%' }}
      placeholder={placeholder}
      treeNodeFilterProp="title"
      showCheckedStrategy="SHOW_ALL"
      maxTagCount="responsive"
      treeDefaultExpandAll
      onChange={(value, labelList, extra) => onNodeChange(value, labelList, extra)}
      treeData={renderTreeNodes(list).filter(item => item.children?.length)}
    />
  ) : null
}

export default TreeNodeSelect
