import React, { useContext, useEffect, useMemo } from 'react'
import ReactFlow, { Background, MiniMap, Controls } from 'react-flow-renderer'
import { Actions, FlowContext, initialElements } from '../../context'

import type { Elements, NodeTypesType, EdgeTypesType } from 'react-flow-renderer'
import { CommonNode, InputNode, OutputNode } from '../Node'
import { CommonEdge } from '../Edge'

const edgeTypes: EdgeTypesType = {
  common: CommonEdge
}

// type flowProcessDataItem = {
//   approvalType: ApprovalType
//   approvalMethod: ApprovalMethod
//   approvalAccounts: { ID: string; name: string }[]
// }

type FlowGrophProps = {
  dataID: string
  flowProcess: Elements
  readPretty: boolean
  flowProcessData: API.ApprovalProcessItem[]
}
const FlowGroph: React.FC<FlowGrophProps> = ({
  dataID,
  flowProcess,
  flowProcessData,
  readPretty
}) => {
  const { flowState, dispatch } = useContext(FlowContext)
  const nodeTypes: NodeTypesType = useMemo(
    () => ({
      start: InputNode,
      end: OutputNode,
      common: CommonNode
    }),
    []
  )

  const { elements } = flowState

  const defaultOptions = {
    nodesDraggable: false, // 不可拖拽
    // zoomOnScroll: false, // 使用鼠标滚轮或触控板放大和缩小图形
    zoomOnPinch: false, // 使用捏合放大和缩小图形
    // snapToGrid: true,
    onLoad: reactFlowInstance => {
      const payload = {}
      if (flowProcess?.length) {
        payload.elements = flowProcess
        payload.flowData = new Map(
          Object.entries(
            flowProcessData.reduce((prev, curr) => {
              if (curr.ID) {
                prev[curr.ID] = curr.participantInfo
              }
              return prev
            }, {})
          )
        )
      }
      payload.flowInstance = reactFlowInstance
      payload.dataID = dataID
      payload.readPretty = readPretty

      dispatch({
        type: Actions.INIT_FLOW_CONTEXT,
        payload
      })
      setTimeout(() => {
        reactFlowInstance?.fitView()
      }, 0)
    }
  }

  const controlsOptions = {
    showZoom: true,
    showFitView: false,
    showInteractive: false
  }

  return (
    <ReactFlow {...defaultOptions} elements={elements} nodeTypes={nodeTypes} edgeTypes={edgeTypes}>
      <MiniMap />
      <Background />
      <Controls {...controlsOptions} className="text-xl" />
    </ReactFlow>
  )
}

export default FlowGroph
