import { CloudUploadOutlined } from '@ant-design/icons'
import { useContext } from 'react'
import { Button, message, Modal } from 'antd'
import { FlowContext, InitialState } from '../../context'
import { addApprovalFlow } from '@/services/api/project'
import consts from '@/utils/consts'
import { isNode } from 'react-flow-renderer'
import type { Elements } from 'react-flow-renderer'

export default function ToolBar(props: {
  dataId: string
  closeAnimateContent: (visible: boolean) => void
}) {
  const { dataId, closeAnimateContent } = props
  const { flowState } = useContext(FlowContext)

  const validate = (elements: Elements) => {
    return elements.filter(item => isNode(item)).length > 2
  }

  const handleSave = () => {
    // const formData = {
    //   nodeData: { ...flowState.flowData }
    // }
    if (!validate(flowState.elements)) {
      return message.warning('请添加审批人')
    }
    Modal.confirm({
      title: '确定发布该审批流程',
      okText: '确定',
      cancelText: '取消',
      onOk: async () => {
        const { code = -1 } = await addApprovalFlow({
          ID: dataId,
          flowProcess: flowState.elements,
          flowProcessData: Object.fromEntries(flowState.flowData.entries())
        })
        if (code === consts.RET_CODE.SUCCESS) {
          message.success('发布成功')
          closeAnimateContent(false)
        }
      }
    })
  }

  return (
    <div className="absolute l-0 t-0 z-10">
      <Button onClick={handleSave} icon={<CloudUploadOutlined />} type="primary">
        发布流程
      </Button>
    </div>
  )
}

export const LoadingBar = () => {
  const {
    flowState: { canvasLoading = false }
  } = useContext(FlowContext)
  return (
    <div className="absolute bottom-11 left-7 text-gray-400 text-base">
      {canvasLoading && <span>正在保存...</span>}
    </div>
  )
}
