import React, { useState, useEffect } from 'react'
import { ReactFlowProvider } from 'react-flow-renderer'
import { FlowContextProvider } from './context'
import FlowGroph from './components/Graph'
import FlowDrawer from './components/Drawer'
import { useRequest } from '@umijs/max'
import { queryApprovalDetail } from '@/services/api/project'
import './index.less'
import { LoadingBar } from './components/Toolbar'

type ApprovalFlowProps = {
  dataID: string
  readPretty: boolean
}

const ApprovalFlow: React.FC<ApprovalFlowProps> = ({ readPretty, dataID }) => {
  const [state, setState] = useState({
    flowProcess: null,
    flowProcessData: null
  })
  const { run: tryGetDetail } = useRequest(queryApprovalDetail, {
    manual: true,
    onSuccess: result => {
      setState({ ...state, flowProcess: result.flowProcess, flowProcessData: result.process })
    }
  })
  useEffect(() => {
    if (dataID) tryGetDetail({ ID: dataID })
  }, [dataID])

  const { flowProcess, flowProcessData } = state
  return (
    <div className="flow-container h-full w-full">
      <FlowContextProvider>
        <ReactFlowProvider>
          {/** 顶部工具栏 */}
          {/* <ToolBar dataId={props.dataID} closeAnimateContent={props.closeAnimateContent} /> */}
          <div className="h-full w-full">
            {flowProcess ? (
              <FlowGroph
                readPretty={readPretty}
                dataID={dataID}
                flowProcess={flowProcess}
                flowProcessData={flowProcessData}
              />
            ) : null}
          </div>
          <LoadingBar />
          <FlowDrawer />
        </ReactFlowProvider>
      </FlowContextProvider>
    </div>
  )
}

export default ApprovalFlow
