import 'antd/dist/antd.less'
import type { FC } from 'react'
import { useMemo } from 'react'
import {
  Designer, // 设计器根组件，主要用于下发上下文
  Workspace, // 工作区组件，核心组件，用于管理工作区内的拖拽行为，树节点数据等等...
  ResourceWidget, // 拖拽源挂件
  StudioPanel, // 主布局面板
  WorkspacePanel, // 工作区布局面板
  ViewportPanel, // 视口布局面板
  ViewPanel, // 视图布局面板
  SettingsPanel, // 右侧配置表单布局面板
  ComponentTreeWidget, // 组件树渲染器
  CompositePanel, // 左侧组合布局面板
  ToolbarPanel, // 工具栏布局面板
  ViewToolsWidget // 视图切换工具挂件
} from '@designable/react'
import { SettingsForm } from '@designable/react-settings-form'
import { createDesigner, GlobalRegistry, Shortcut, KeyCode } from '@designable/core'
import { ActionsWidget, PreviewWidget, SchemaEditorWidget } from './widgets'
import { saveSchema } from './service'
import {
  Form,
  Field,
  Input,
  Select,
  TreeSelect,
  Cascader,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  Switch,
  FormGrid,
  FormLayout
} from './antd'
import { connect, useParams } from '@umijs/max'

GlobalRegistry.registerDesignerLocales({
  'zh-CN': {
    sources: {
      Inputs: '输入控件',
      Layouts: '布局组件'
    }
  }
})

interface DesignableProps {
  title: string
}
const Designable: FC<DesignableProps> = ({ base, title }) => {
  const { id: columnType } = useParams()

  const engine = useMemo(
    () =>
      createDesigner({
        shortcuts: [
          new Shortcut({
            codes: [
              [KeyCode.Meta, KeyCode.S],
              [KeyCode.Control, KeyCode.S]
            ],
            handler(ctx) {
              saveSchema(ctx.engine)
            }
          })
        ],
        rootComponentName: 'Form'
      }),
    []
  )

  return (
    <Designer engine={engine} position="relative">
      <StudioPanel
        logo={<span className="text-base font-medium">{title}</span>}
        actions={
          <ActionsWidget
            schema={{
              form: {
                labelCol: 6,
                wrapperCol: 12,
                fullness: true,
                inset: false
              },
              schema: base[columnType]
            }}
          />
        }>
        <CompositePanel>
          <CompositePanel.Item title="panels.Component" icon="Component">
            <ResourceWidget
              title="sources.Inputs"
              sources={[
                Input,
                Password,
                NumberPicker,
                Select,
                TreeSelect,
                Cascader,
                Checkbox,
                Radio,
                Switch,
                DatePicker,
                TimePicker
              ]}
            />
            <ResourceWidget title="sources.Layouts" sources={[FormGrid, FormLayout]} />
          </CompositePanel.Item>
        </CompositePanel>

        <Workspace id="form">
          <WorkspacePanel>
            <ToolbarPanel>
              <ViewToolsWidget use={['DESIGNABLE', 'JSONTREE', 'PREVIEW']} />
            </ToolbarPanel>
            <ViewportPanel>
              <ViewPanel type="DESIGNABLE">
                {() => (
                  <ComponentTreeWidget
                    components={{
                      Form,
                      Field,
                      Input,
                      Select,
                      TreeSelect,
                      Cascader,
                      Radio,
                      Checkbox,
                      NumberPicker,
                      Password,
                      DatePicker,
                      TimePicker,
                      Switch,
                      FormGrid,
                      FormLayout
                    }}
                  />
                )}
              </ViewPanel>
              <ViewPanel type="JSONTREE" scrollable={false}>
                {(tree, onChange) => <SchemaEditorWidget tree={tree} onChange={onChange} />}
              </ViewPanel>
              <ViewPanel type="PREVIEW">{tree => <PreviewWidget tree={tree} />}</ViewPanel>
            </ViewportPanel>
          </WorkspacePanel>
        </Workspace>
        <SettingsPanel title="panels.PropertySettings">
          <SettingsForm uploadAction="https://www.mocky.io/v2/5cc8019d300000980a055e76" />
        </SettingsPanel>
      </StudioPanel>
    </Designer>
  )
}

export default connect(({ schemaBase }: { schemaBase: SchemaBaseModelState }) => ({
  base: schemaBase.base
}))(Designable)
