import React, { useEffect } from 'react'
import { Space, Button, message } from 'antd'
import { useDesigner, TextWidget } from '@designable/react'
import { GlobalRegistry } from '@designable/core'
import { observer } from '@formily/react'
import { loadInitialSchema } from '../service'
import { useDispatch, history, useParams, useRequest } from '@umijs/max'
import { transformToSchema } from '@designable/formily-transformer'
import { updateSchema } from '@/services/api/schema'

export const ActionsWidget = observer(({ schema }) => {
  const designer = useDesigner()
  const { id: columnType } = useParams()
  useEffect(() => {
    schema && loadInitialSchema(designer, schema)
    GlobalRegistry.setDesignerLanguage('zh-cn')
  }, [schema])
  const dispatch = useDispatch()
  const { run: tryUpdateSchema } = useRequest(updateSchema, {
    manual: true,
    onSuccess: result => {
      message.success('更新成功')
      dispatch({
        type: 'schemaBase/changeSchemaByColumnType',
        payload: {
          columnType,
          schema: result.schema
        }
      })
    }
  })

  const saveSchema = () => {
    tryUpdateSchema({
      columnType,
      schema: JSON.stringify(transformToSchema(designer.getCurrentTree()).schema)
    })
  }
  return (
    <Space style={{ marginRight: 10 }}>
      <Button onClick={() => history.replace('/schema/base')}>
        <TextWidget>返回</TextWidget>
      </Button>
      <Button type="primary" onClick={() => saveSchema(designer)}>
        <TextWidget>Publish</TextWidget>
      </Button>
    </Space>
  )
})
