import React from 'react'
import { Input as FormilyInput } from '@formily/antd'
import { createBehavior, createResource } from '@designable/core'
import { DnFC } from '@designable/react'
import { createFieldSchema } from '../Field'
import { AllSchemas } from '../../schemas'
import { AllLocales } from '../../locales'

export const Input: DnFC<React.ComponentProps<typeof FormilyInput>> = FormilyInput

Input.Behavior = createBehavior(
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gsCode',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目编号' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gsName',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目名称' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gcName',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '工程名称' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gzAddress',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '工程地址' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'institution',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '单位' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'ministry',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '行业主管部门' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'bUnit',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '建设单位' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'fax',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '传真' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'pCorporation',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目法人' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'pMobile',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '联系电话' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'pMail',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目联系人邮箱' } }
  }
)

Input.Resource = createResource(
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目编号',
          name: 'gsCode',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目名称',
          name: 'gsName',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '工程名称',
          name: 'gcName',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '工程地址',
          name: 'gzAddress',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '单位',
          name: 'institution',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '行业主管部门',
          name: 'ministry',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '建设单位',
          name: 'bUnit',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '传真',
          name: 'fax',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目法人',
          name: 'pCorporation',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '联系电话',
          name: 'pMobile',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目联系人邮箱',
          name: 'pMail',
          'x-decorator': 'FormItem',
          'x-component': 'Input'
        }
      }
    ]
  }
)
