import { queryTemplateList } from '@/services/api/schema'
import { PageContainer } from '@ant-design/pro-layout'
import React, { useEffect, useMemo, useState } from 'react'
import { history, useRequest, connect, useDispatch } from '@umijs/max'
import { createForm } from '@formily/core'
import { createSchemaField } from '@formily/react'
import {
  FormItem,
  Input,
  Switch,
  Select,
  FormGrid,
  FormLayout,
  Form,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  TreeSelect
} from '@formily/antd'
import { Button } from 'antd'
import LeftMenu from '../Base/components/LeftMenu'
import { isString } from '@/utils/is'

type iState = {
  menuData?: API.TemplateListItem[]
  activeKey?: string
}

const Budget: React.FC = () => {
  const dispatch = useDispatch()
  const [state, setState] = useState<iState>({
    menuData: [],
    activeKey: null
  })
  useEffect(() => {
    if (state.menuData?.length) {
      dispatch({
        type: 'templateSchema/changeSchemaByColumnType',
        payload: state.menuData
      })
    }
  }, [state.menuData])
  useRequest(queryTemplateList, {
    onSuccess: (result: API.TemplateListItem[]) => {
      setState({
        ...state,
        menuData: result,
        activeKey: result?.[0].action
      })
    }
  })

  const currentSchema = useMemo(() => {
    const schema = state.menuData?.find(item => item.action === state.activeKey)?.schema
    if (schema && isString(schema)) {
      return JSON.parse(schema)
    }
    return {}
  }, [state.activeKey])
  const renderForm = () => {
    const normalForm = createForm({
      validateFirst: true,
      pattern: 'readOnly'
    })

    const SchemaField = createSchemaField({
      components: {
        FormLayout,
        FormItem,
        FormGrid,
        Input,
        Switch,
        Select,
        Radio,
        Checkbox,
        NumberPicker,
        Password,
        DatePicker,
        TimePicker,
        TreeSelect
      }
    })
    return (
      <Form form={normalForm} labelCol={4} wrapperCol={8}>
        <SchemaField schema={currentSchema} />
      </Form>
    )
  }

  return (
    <PageContainer title={false}>
      <div className="h-full w-full flex flex-row">
        {state.activeKey && (
          <LeftMenu
            title="表单列表"
            options={state.menuData.map(item => ({ label: item.name, value: item.action }))}
            value={state.activeKey}
            onChange={key => setState({ ...state, activeKey: key })}
          />
        )}

        <div className="w-6/7 ml-8 bg-white p-4  rounded-20px shadow-hex-3e2c5a relative">
          <div className="flex justify-end">
            {state.activeKey && (
              <Button type="primary" onClick={() => history.push(`/schema/budget/${state.activeKey}`)}>
                编辑
              </Button>
            )}
          </div>
          <div className="w-600px">{renderForm()}</div>
        </div>
      </div>
    </PageContainer>
  )
}

export default Budget
