import { getSchemaByColmunType, queryBudgetTemplateDetail } from '@/services/api/schema'
import consts from '@/utils/consts'
import { isArray } from '@/utils/is'
import type { Effect, Reducer } from '@umijs/max'

export type TemplateSchemaModelState = Record<
  string,
  {
    ID: string
    columnType: number
    schema: string
  }
>

export interface TemplateSchemaType {
  namespace: 'templateSchema'
  state: TemplateSchemaModelState
  effects: {
    querySchema: Effect
  }
  reducers: {
    save: Reducer<TemplateSchemaModelState>
    // 启用 immer 之后
    // save: ImmerReducer<ProjectModelState>;
  }
}

const TemplateSchemaModel: TemplateSchemaType = {
  namespace: 'templateSchema',
  state: {},
  effects: {
    *querySchema({ payload }, { call, put }) {
      const response = yield call(queryBudgetTemplateDetail, payload)
      if (response?.code === consts.RET_CODE.SUCCESS) {
        yield put({
          type: 'save',
          payload: {
            ...(response.data || {})
          }
        })
      }
    },
    *changeSchemaByColumnType({ payload }, { put }) {
      yield put({
        type: 'save',
        payload
      })
    }
  },
  reducers: {
    save(state, action) {
      if (isArray(action.payload)) {
        const schemaArrToMap = action.payload.reduce((prev, curr) => {
          const schema = curr?.schema && JSON.parse(curr?.schema)
          return { ...prev, [curr.action]: { ...curr, schema } }
        }, {})
        return { ...state, ...schemaArrToMap }
      } else {
        const schema = action.payload?.schema && JSON.parse(action.payload?.schema)
        return {
          ...state,
          [action.payload.action]: { ...state[action.payload.action], ...action.payload, schema }
        }
      }
    }
  }
}

export default TemplateSchemaModel
